@@ -1,5 +1,6 @@
 # coding: utf-8
 class Singleton(type):
+    """Singleton abstrace class"""
     _instances = {}
     # https://stackoverflow.com/questions/6760685/creating-a-singleton-in-python
     def __call__(cls, *args, **kwargs):
@@ -8,6 +9,9 @@ class Singleton(type):
                 Singleton, cls).__call__(*args, **kwargs)
         return cls._instances[cls]
 class NoThing(metaclass=Singleton):
-    '''Singleton Class to mimic None'''
+    '''Singleton Class to mimic null'''
 
 NO_THING = NoThing()
+"""
+Singleton Class instance that represents null object.
+"""
